<?php

/**
 * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
 * See https://www.x-cart.com/license-agreement.html for license details.
 */

namespace XLite\View\FormField\Select;

/**
 * Root categories look selector
 */
class RootCategoriesLook extends \XLite\View\FormField\Select\Regular
{
    /**
     * Get default options
     *
     * @return array
     */
    protected function getDefaultOptions()
    {
        return [
            'list'  => static::t('List'),
            'icons' => static::t('Icons'),
            'hide'  => static::t('Hide'),
        ];
    }
}
